pub struct Input<M: Display> { /* private fields */ }Expand description
Input struct
Examples
use may_clack::{input, cancel};
let answer = input("message")
.initial_value("initial_value")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact();
println!("answer {:?}", answer);
fn do_cancel() {
cancel!("operation cancelled");
std::process::exit(1);
}Implementations
sourceimpl<M: Display> Input<M>
impl<M: Display> Input<M>
sourcepub fn placeholder<S: Into<String>>(&mut self, placeholder: S) -> &mut Self
pub fn placeholder<S: Into<String>>(&mut self, placeholder: S) -> &mut Self
Specify a placeholder.
Examples
use may_clack::input;
let answer = input("message").placeholder("placeholder").required();
println!("answer {:?}", answer);Examples found in repository?
examples/full.rs (line 14)
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47
fn main() -> Result<(), ClackError> {
println!();
intro!(" full ".reversed());
info!("visit the documentation at https://docs.rs/may-clack");
let do_input = input("input")
.placeholder("placeholder")
.cancel(do_cancel)
.required()?;
let do_multi_input = multi_input("multi input")
.max(4)
.cancel(do_cancel)
.interact()?;
let do_confirm = confirm("confirm")
.prompts("true", "false")
.cancel(do_cancel)
.interact()?;
let do_multi_select = multi_select("multi select")
.option("opt1", "option 1")
.option("opt2", "option 2")
.option_hint("opt3", "option 3", "hint")
.cancel(do_cancel)
.interact()?;
let do_select = select("select")
.option("val1", "value 1")
.option("val2", "value 2")
.option_hint("val 3", "value 3", "hint")
.cancel(do_cancel)
.interact()?;
outro!();
println!("input {:?}", do_input);
println!("confirm {:?}", do_confirm);
println!("multi_input {:?}", do_multi_input);
println!("multi_select {:?}", do_multi_select);
println!("select {:?}", do_select);
Ok(())
}sourcepub fn initial_value<S: Into<String>>(&mut self, initial_value: S) -> &mut Self
pub fn initial_value<S: Into<String>>(&mut self, initial_value: S) -> &mut Self
Specify the initial value.
Examples
use may_clack::input;
let answer = input("message").initial_value("initial_value").interact();
println!("answer {:?}", answer);sourcepub fn validate<F>(&mut self, validate: F) -> &mut Selfwhere
F: Fn(&str) -> Option<&'static str> + 'static,
pub fn validate<F>(&mut self, validate: F) -> &mut Selfwhere F: Fn(&str) -> Option<&'static str> + 'static,
Specify a validation function.
On a successful validation, return a None from the closure,
and on an unsuccessful validation return a Some<&'static str> with the error message.
Examples
use may_clack::input;
let answer = input("message")
.validate(|x| (!x.is_ascii()).then_some("only use ascii characters"))
.interact();
println!("answer {:?}", answer);Examples found in repository?
examples/validate.rs (line 9)
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29
fn main() -> Result<(), ClackError> {
println!();
intro!(" validate ".reversed());
let do_validate_input = input("validate single")
.validate(|x| (!x.is_ascii()).then_some("only use ascii characters"))
.cancel(do_cancel)
.required()?;
let do_validate_multi_input = multi_input("validate multi")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact()?;
let do_parse_input = input("parse to u8").cancel(do_cancel).parse::<u8>()?;
let do_parse_multi = multi_input("parse multiple to u8")
.cancel(do_cancel)
.parse::<u8>()?;
outro!();
println!("single {:?}", do_validate_input);
println!("multi {:?}", do_validate_multi_input);
println!("parse single {:?}", do_parse_input);
println!("parse multi {:?}", do_parse_multi);
Ok(())
}sourcepub fn cancel<F>(&mut self, cancel: F) -> &mut Selfwhere
F: Fn() + 'static,
pub fn cancel<F>(&mut self, cancel: F) -> &mut Selfwhere F: Fn() + 'static,
Specify function to call on cancel.
Examples
use may_clack::{input, cancel};
let answer = input("message").cancel(do_cancel).interact();
println!("answer {:?}", answer);
fn do_cancel() {
cancel!("operation cancelled");
panic!("operation cancelled");
}Examples found in repository?
examples/validate.rs (line 10)
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29
fn main() -> Result<(), ClackError> {
println!();
intro!(" validate ".reversed());
let do_validate_input = input("validate single")
.validate(|x| (!x.is_ascii()).then_some("only use ascii characters"))
.cancel(do_cancel)
.required()?;
let do_validate_multi_input = multi_input("validate multi")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact()?;
let do_parse_input = input("parse to u8").cancel(do_cancel).parse::<u8>()?;
let do_parse_multi = multi_input("parse multiple to u8")
.cancel(do_cancel)
.parse::<u8>()?;
outro!();
println!("single {:?}", do_validate_input);
println!("multi {:?}", do_validate_multi_input);
println!("parse single {:?}", do_parse_input);
println!("parse multi {:?}", do_parse_multi);
Ok(())
}More examples
examples/full.rs (line 15)
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47
fn main() -> Result<(), ClackError> {
println!();
intro!(" full ".reversed());
info!("visit the documentation at https://docs.rs/may-clack");
let do_input = input("input")
.placeholder("placeholder")
.cancel(do_cancel)
.required()?;
let do_multi_input = multi_input("multi input")
.max(4)
.cancel(do_cancel)
.interact()?;
let do_confirm = confirm("confirm")
.prompts("true", "false")
.cancel(do_cancel)
.interact()?;
let do_multi_select = multi_select("multi select")
.option("opt1", "option 1")
.option("opt2", "option 2")
.option_hint("opt3", "option 3", "hint")
.cancel(do_cancel)
.interact()?;
let do_select = select("select")
.option("val1", "value 1")
.option("val2", "value 2")
.option_hint("val 3", "value 3", "hint")
.cancel(do_cancel)
.interact()?;
outro!();
println!("input {:?}", do_input);
println!("confirm {:?}", do_confirm);
println!("multi_input {:?}", do_multi_input);
println!("multi_select {:?}", do_multi_select);
println!("select {:?}", do_select);
Ok(())
}sourcepub fn parse<T: FromStr + Display>(&self) -> Result<T, ClackError>where
T::Err: Display,
pub fn parse<T: FromStr + Display>(&self) -> Result<T, ClackError>where T::Err: Display,
Like Input::required(), but parses the value before returning.
Useful for getting number inputs.
Examples
use may_clack::input;
let answer: i32 = input("message").parse::<i32>()?;
println!("answer {:?}", answer);Examples found in repository?
examples/validate.rs (line 16)
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29
fn main() -> Result<(), ClackError> {
println!();
intro!(" validate ".reversed());
let do_validate_input = input("validate single")
.validate(|x| (!x.is_ascii()).then_some("only use ascii characters"))
.cancel(do_cancel)
.required()?;
let do_validate_multi_input = multi_input("validate multi")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact()?;
let do_parse_input = input("parse to u8").cancel(do_cancel).parse::<u8>()?;
let do_parse_multi = multi_input("parse multiple to u8")
.cancel(do_cancel)
.parse::<u8>()?;
outro!();
println!("single {:?}", do_validate_input);
println!("multi {:?}", do_validate_multi_input);
println!("parse single {:?}", do_parse_input);
println!("parse multi {:?}", do_parse_multi);
Ok(())
}sourcepub fn required(&self) -> Result<String, ClackError>
pub fn required(&self) -> Result<String, ClackError>
Like Input::interact(), but does not return an empty line.
Examples
use may_clack::input;
let answer = input("message").required();
println!("answer {:?}", answer);Examples found in repository?
examples/validate.rs (line 11)
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29
fn main() -> Result<(), ClackError> {
println!();
intro!(" validate ".reversed());
let do_validate_input = input("validate single")
.validate(|x| (!x.is_ascii()).then_some("only use ascii characters"))
.cancel(do_cancel)
.required()?;
let do_validate_multi_input = multi_input("validate multi")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact()?;
let do_parse_input = input("parse to u8").cancel(do_cancel).parse::<u8>()?;
let do_parse_multi = multi_input("parse multiple to u8")
.cancel(do_cancel)
.parse::<u8>()?;
outro!();
println!("single {:?}", do_validate_input);
println!("multi {:?}", do_validate_multi_input);
println!("parse single {:?}", do_parse_input);
println!("parse multi {:?}", do_parse_multi);
Ok(())
}More examples
examples/full.rs (line 16)
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47
fn main() -> Result<(), ClackError> {
println!();
intro!(" full ".reversed());
info!("visit the documentation at https://docs.rs/may-clack");
let do_input = input("input")
.placeholder("placeholder")
.cancel(do_cancel)
.required()?;
let do_multi_input = multi_input("multi input")
.max(4)
.cancel(do_cancel)
.interact()?;
let do_confirm = confirm("confirm")
.prompts("true", "false")
.cancel(do_cancel)
.interact()?;
let do_multi_select = multi_select("multi select")
.option("opt1", "option 1")
.option("opt2", "option 2")
.option_hint("opt3", "option 3", "hint")
.cancel(do_cancel)
.interact()?;
let do_select = select("select")
.option("val1", "value 1")
.option("val2", "value 2")
.option_hint("val 3", "value 3", "hint")
.cancel(do_cancel)
.interact()?;
outro!();
println!("input {:?}", do_input);
println!("confirm {:?}", do_confirm);
println!("multi_input {:?}", do_multi_input);
println!("multi_select {:?}", do_multi_select);
println!("select {:?}", do_select);
Ok(())
}sourcepub fn interact(&self) -> Result<Option<String>, ClackError>
pub fn interact(&self) -> Result<Option<String>, ClackError>
Waits for the user to submit a line of text.
Returns None on an empty line and Some::<String> otherwise.
Examples
use may_clack::{input, cancel};
let answer = input("message")
.initial_value("initial_value")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact();
println!("answer {:?}", answer);
fn do_cancel() {
cancel!("operation cancelled");
std::process::exit(1);
}Auto Trait Implementations
impl<M> !RefUnwindSafe for Input<M>
impl<M> !Send for Input<M>
impl<M> !Sync for Input<M>
impl<M> Unpin for Input<M>where M: Unpin,
impl<M> !UnwindSafe for Input<M>