Struct may_clack::multi_input::MultiInput
source · pub struct MultiInput<M: Display> { /* private fields */ }Expand description
MultiInput struct
Examples
use may_clack::{multi_input, cancel};
let answers = multi_input("message")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact();
println!("answers {:?}", answers);
fn do_cancel() {
cancel!("operation cancelled");
std::process::exit(1);
}Implementations
sourceimpl<M: Display> MultiInput<M>
impl<M: Display> MultiInput<M>
sourcepub fn new(message: M) -> Self
pub fn new(message: M) -> Self
Creates a new MultiInput struct.
Has a shorthand version in multi_input()
Examples
use may_clack::{multi_input, multi_input::MultiInput};
// these two are equivalent
let question = MultiInput::new("message");
let question = multi_input("message");sourcepub fn placeholder(&mut self) -> &mut Self
pub fn placeholder(&mut self) -> &mut Self
Todo
sourcepub fn initial_value<S: Into<String>>(&mut self, initial_value: S) -> &mut Self
pub fn initial_value<S: Into<String>>(&mut self, initial_value: S) -> &mut Self
Specify the initial value.
Examples
use may_clack::multi_input;
let answers = multi_input("message").initial_value("initial_value").interact();
println!("answers {:?}", answers);sourcepub fn min(&mut self, min: u16) -> &mut Self
pub fn min(&mut self, min: u16) -> &mut Self
Specify the minimum amount of answers.
use may_clack::multi_input;
let answers = multi_input("message").min(2).interact();
println!("answers {:?}", answers)sourcepub fn max(&mut self, max: u16) -> &mut Self
pub fn max(&mut self, max: u16) -> &mut Self
Specify the maximum amount of answers. Will automatically submit when that amount is reached.
Examples
use may_clack::multi_input;
let answers = multi_input("message").max(4).interact();
println!("answers {:?}", answers);Examples found in repository?
examples/full.rs (line 18)
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47
fn main() -> Result<(), ClackError> {
println!();
intro!(" full ".reversed());
info!("visit the documentation at https://docs.rs/may-clack");
let do_input = input("input")
.default_value("default")
.cancel(do_cancel)
.interact()?;
let do_multi_input = multi_input("multi input")
.max(4)
.cancel(do_cancel)
.interact()?;
let do_confirm = confirm("confirm")
.prompts("true", "false")
.cancel(do_cancel)
.interact()?;
let do_multi_select = multi_select("multi select")
.option("opt1", "option 1")
.option("opt2", "option 2")
.option_hint("opt3", "option 3", "hint")
.cancel(do_cancel)
.interact()?;
let do_select = select("select")
.option("val1", "value 1")
.option("val2", "value 2")
.option_hint("val 3", "value 3", "hint")
.cancel(do_cancel)
.interact()?;
outro!();
println!("input {:?}", do_input);
println!("confirm {:?}", do_confirm);
println!("multi_input {:?}", do_multi_input);
println!("multi_select {:?}", do_multi_select);
println!("select {:?}", do_select);
Ok(())
}sourcepub fn validate<F>(&mut self, validate: F) -> &mut Selfwhere
F: Fn(&str) -> Option<&'static str> + 'static,
pub fn validate<F>(&mut self, validate: F) -> &mut Selfwhere F: Fn(&str) -> Option<&'static str> + 'static,
Specify a validation function.
On a successful validation, return a None from the closure,
and on an unsuccessful validation return a Some<&'static str> with the error message.
Examples
use may_clack::multi_input;
let answers = multi_input("message")
.validate(|x| (!x.is_ascii()).then_some("only use ascii characters"))
.interact();
println!("answers {:?}", answers);Examples found in repository?
examples/validate.rs (line 13)
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23
fn main() -> Result<(), ClackError> {
println!();
intro!(" validate ".reversed());
let do_validate_input = input("validate single")
.validate(|x| (!x.is_ascii()).then_some("only use ascii characters"))
.cancel(do_cancel)
.required();
let do_validate_multi_input = multi_input("validate multi")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact();
outro!();
println!("single {:?}", do_validate_input);
println!("multi {:?}", do_validate_multi_input);
Ok(())
}sourcepub fn cancel<F>(&mut self, cancel: F) -> &mut Selfwhere
F: Fn() + 'static,
pub fn cancel<F>(&mut self, cancel: F) -> &mut Selfwhere F: Fn() + 'static,
Specify function to call on cancel.
Examples
use may_clack::{multi_input, cancel};
let answers = multi_input("message").cancel(do_cancel).interact();
println!("answers {:?}", answers);
fn do_cancel() {
cancel!("operation cancelled");
panic!("operation cancelled");
}Examples found in repository?
examples/generic.rs (line 10)
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19
fn main() -> Result<(), ClackError> {
println!();
intro!(" generic messages ".reversed());
let number = confirm(20).cancel(do_cancel).interact()?;
let styled = multi_input("style".on_cyan())
.cancel(do_cancel)
.interact()?;
outro!();
println!("number {:?}", number);
println!("styled {:?}", styled);
Ok(())
}More examples
examples/validate.rs (line 14)
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23
fn main() -> Result<(), ClackError> {
println!();
intro!(" validate ".reversed());
let do_validate_input = input("validate single")
.validate(|x| (!x.is_ascii()).then_some("only use ascii characters"))
.cancel(do_cancel)
.required();
let do_validate_multi_input = multi_input("validate multi")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact();
outro!();
println!("single {:?}", do_validate_input);
println!("multi {:?}", do_validate_multi_input);
Ok(())
}examples/full.rs (line 19)
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47
fn main() -> Result<(), ClackError> {
println!();
intro!(" full ".reversed());
info!("visit the documentation at https://docs.rs/may-clack");
let do_input = input("input")
.default_value("default")
.cancel(do_cancel)
.interact()?;
let do_multi_input = multi_input("multi input")
.max(4)
.cancel(do_cancel)
.interact()?;
let do_confirm = confirm("confirm")
.prompts("true", "false")
.cancel(do_cancel)
.interact()?;
let do_multi_select = multi_select("multi select")
.option("opt1", "option 1")
.option("opt2", "option 2")
.option_hint("opt3", "option 3", "hint")
.cancel(do_cancel)
.interact()?;
let do_select = select("select")
.option("val1", "value 1")
.option("val2", "value 2")
.option_hint("val 3", "value 3", "hint")
.cancel(do_cancel)
.interact()?;
outro!();
println!("input {:?}", do_input);
println!("confirm {:?}", do_confirm);
println!("multi_input {:?}", do_multi_input);
println!("multi_select {:?}", do_multi_select);
println!("select {:?}", do_select);
Ok(())
}sourcepub fn interact(&self) -> Result<Vec<String>, ClackError>
pub fn interact(&self) -> Result<Vec<String>, ClackError>
Waits for the user to submit a line of text.
Returns None on an empty line and Some::<String> otherwise.
Examples
use may_clack::{multi_input, cancel};
let answers = multi_input("message")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact();
println!("answers {:?}", answers);
fn do_cancel() {
cancel!("operation cancelled");
std::process::exit(1);
}Examples found in repository?
examples/generic.rs (line 11)
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19
fn main() -> Result<(), ClackError> {
println!();
intro!(" generic messages ".reversed());
let number = confirm(20).cancel(do_cancel).interact()?;
let styled = multi_input("style".on_cyan())
.cancel(do_cancel)
.interact()?;
outro!();
println!("number {:?}", number);
println!("styled {:?}", styled);
Ok(())
}More examples
examples/validate.rs (line 15)
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23
fn main() -> Result<(), ClackError> {
println!();
intro!(" validate ".reversed());
let do_validate_input = input("validate single")
.validate(|x| (!x.is_ascii()).then_some("only use ascii characters"))
.cancel(do_cancel)
.required();
let do_validate_multi_input = multi_input("validate multi")
.validate(|x| x.parse::<u32>().err().map(|_| "invalid u32"))
.cancel(do_cancel)
.interact();
outro!();
println!("single {:?}", do_validate_input);
println!("multi {:?}", do_validate_multi_input);
Ok(())
}examples/full.rs (line 20)
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47
fn main() -> Result<(), ClackError> {
println!();
intro!(" full ".reversed());
info!("visit the documentation at https://docs.rs/may-clack");
let do_input = input("input")
.default_value("default")
.cancel(do_cancel)
.interact()?;
let do_multi_input = multi_input("multi input")
.max(4)
.cancel(do_cancel)
.interact()?;
let do_confirm = confirm("confirm")
.prompts("true", "false")
.cancel(do_cancel)
.interact()?;
let do_multi_select = multi_select("multi select")
.option("opt1", "option 1")
.option("opt2", "option 2")
.option_hint("opt3", "option 3", "hint")
.cancel(do_cancel)
.interact()?;
let do_select = select("select")
.option("val1", "value 1")
.option("val2", "value 2")
.option_hint("val 3", "value 3", "hint")
.cancel(do_cancel)
.interact()?;
outro!();
println!("input {:?}", do_input);
println!("confirm {:?}", do_confirm);
println!("multi_input {:?}", do_multi_input);
println!("multi_select {:?}", do_multi_select);
println!("select {:?}", do_select);
Ok(())
}Auto Trait Implementations
impl<M> !RefUnwindSafe for MultiInput<M>
impl<M> !Send for MultiInput<M>
impl<M> !Sync for MultiInput<M>
impl<M> Unpin for MultiInput<M>where M: Unpin,
impl<M> !UnwindSafe for MultiInput<M>